@@ -1,7 +1,6 @@
 from modules import forms
 from ptlibs import ptprinthelper
 
-
 def print_result(list_of_results: list, args):
     """
     Prints or writes processed results in a structured format based on provided arguments.
@@ -25,13 +24,15 @@ def print_result(list_of_results: list, args):
     Returns:
         None: Results are printed to the console or written to files based on arguments.
     """
+
     handlers = {
         "internal_urls_with_parameters": _print_parsed_urls,
         "metadata": _print_metadata,
         "forms": _print_forms,
         "comments": _print_comments,
-        "google_keys": _print_google_keys
+        "google_keys": _print_google_keys,
     }
+
     if not len(list_of_results) > 1:
         for r in list_of_results:
             ptprinthelper.ptprint(" ", "TEXT", condition=not args.json)
@@ -46,6 +47,7 @@ def print_result(list_of_results: list, args):
 
     list_of_results = [l.data for l in list_of_results]
     titles = [i for i in {k: v for k, v in list_of_results[0].items() if v is not None}.keys()]
+
     args.file_handle = None
     if args.output and not args.output_parts:
         args.file_handle = open(args.output, "w")
@@ -60,7 +62,6 @@ def print_result(list_of_results: list, args):
         if args.grouping_complete:
             merged_result = _get_data_type(title)
 
-
         _print_title(title, args, index)
         for index, result_dictionary in enumerate(list_of_results):
 
@@ -70,6 +71,7 @@ def print_result(list_of_results: list, args):
             if args.grouping_complete:
                 merged_result = _fill_merged_result(merged_result, list_of_results, index, title)
 
+            # if not grouping complete
             else:
                 if title == "internal_urls_with_parameters":
                     _print_parsed_urls(list_of_results, index, args)
@@ -88,6 +90,7 @@ def print_result(list_of_results: list, args):
                 _get_endl(list_of_results, index, args)
 
         if args.grouping_complete:
+            # if -gc provided
             if title == "internal_urls_with_parameters":
                 merged_result["internal_urls_with_parameters"] = sorted(merged_result["internal_urls_with_parameters"], key=lambda k: k['url'])
                 _print_parsed_urls([merged_result], index=0, args=args)
@@ -100,16 +103,27 @@ def print_result(list_of_results: list, args):
             elif title == "google_keys":
                 _print_google_keys([merged_result], index=0, args=args)
             elif title == "regex":
+
+                # ----
+                if not merged_result["regex"].keys():
+                    ptprinthelper.ptprint("Not found", "", filehandle=args.file_handle, condition=not args.json)
                 for text, urls in merged_result["regex"].items():
-                    if len(list_of_results) > 1:
-                            max_len = max(len(text) for text in merged_result["regex"].keys())
-                            padding = " " if (max_len - len(text)) > 50 else " " * (max_len - len(text))
-                            ptprinthelper.ptprint(f"{text.strip()}{padding}", "", condition=not args.json, end=" ")
+                    if len(list_of_results) > 1 and args.very_verbose:
+                        max_len = max(len(text) for text in merged_result["regex"].keys())
+                        padding = " " if (max_len - len(text)) > 50 else " " * (max_len - len(text) +1)
+                        ptprinthelper.ptprint(f"{text.strip()}{padding}", "", condition=not args.json, end="\n" if not args.very_verbose else "")
+                        if args.very_verbose:
                             ptprinthelper.ptprint(ptprinthelper.get_colored_text(f"({', '.join(sorted(urls))})", color="ADDITIONS"), "", condition=not args.json)
                     else:
                         ptprinthelper.ptprint(f"{text}", "", condition=not args.json)
+
+                # print dynamic title with unique urls
+                if len(list_of_results) > 1:
+                    ptprinthelper.ptprint(f"{ptprinthelper.get_colored_text('REGEX URLS', color="TITLE")}\n{'-'*len('REGEX URLS')}", "TEXT", condition=not args.json, newline_above=True)
+                    _all_urls = set().union(*merged_result["regex"].values())
+                    ptprinthelper.ptprint("\n".join(sorted(_all_urls)), "", condition=not args.json)
             elif merged_result:
-                ptprinthelper.ptprint("\n".join(sorted(merged_result)), "", end=_check_if_next(list_of_results, index)+"\n", filehandle=args.file_handle, condition=not args.json)
+                ptprinthelper.ptprint("\n".join(sorted(set(merged_result))), "", end=_check_if_next(list_of_results, index)+"\n", filehandle=args.file_handle, condition=not args.json)
             else:
                 ptprinthelper.ptprint("Not found", "", filehandle=args.file_handle, condition=not args.json)
 
@@ -120,7 +134,6 @@ def print_result(list_of_results: list, args):
         args.file_handle.close()
 
 
-
 def _get_handle(title, args):
     parsed_file_name = args.output.rsplit(".", 1)
     file_extension = "." + parsed_file_name[-1] if len(parsed_file_name) > 1 else ""
@@ -140,6 +153,8 @@ def _print_google_keys(list_of_results, index, args):
         ptprinthelper.ptprint("Not found", "TEXT", not args.json, filehandle=args.file_handle)
 
 def _print_title(title, args, index=0):
+    if title == "regex":
+        title = "REGEX SEARCH"
     if args.file_handle and index > 0:
         args.file_handle.write("\n")
     #ptprinthelper.ptprint(f'\n{ptprinthelper.get_colored_text(title.upper().replace("_", " "), color="TITLE")}{"" * len(title)}', "", filehandle=args.file_handle, condition=not args.json)
@@ -338,6 +353,7 @@ def _fill_merged_result(merged_result, list_of_results, index, title):
     elif title == "comments":
         for key, value_list in (list_of_results[index].get("comments") or {}).items():
             merged_result["comments"][key].extend(value_list)
+            merged_result["comments"][key] = list(set(merged_result["comments"][key]))
 
     elif title == "google_keys":
         merged_result.setdefault("google_keys", {})
